@@ -1,14 +1,9 @@
 package Tapper::Producer;
-# git description: v4.1.2-2-gb3a4473
+# git description: v4.1.3-1-g7fc9474
 
-BEGIN {
-  $Tapper::Producer::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Producer::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Precondition producers (base class)
-
+$Tapper::Producer::VERSION = '5.0.0';
 use warnings;
 use strict;
 
@@ -34,7 +29,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -61,7 +56,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
