@@ -1,13 +1,8 @@
 ## no critic (RequireUseStrict)
 package Tapper::Producer::DummyProducer;
-BEGIN {
-  $Tapper::Producer::DummyProducer::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Producer::DummyProducer::VERSION = '4.1.3';
-}
-
-        use Moose;
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Producer::DummyProducer::VERSION = '5.0.0';
+use Moose;
 
 
         sub produce {
@@ -28,7 +23,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -44,7 +39,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
