@@ -1,13 +1,8 @@
 ## no critic (RequireUseStrict)
 package Tapper::Producer::ExternalProgram;
-BEGIN {
-  $Tapper::Producer::ExternalProgram::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Producer::ExternalProgram::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: produce preconditions via external program
-
+$Tapper::Producer::ExternalProgram::VERSION = '5.0.0';
 use Moose;
 use File::Temp 'tempfile';
 use YAML       'Load';
@@ -64,7 +59,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -88,7 +83,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
