@@ -1,14 +1,9 @@
 ## no critic (RequireUseStrict)
 package Tapper::Producer::Kernel;
-BEGIN {
-  $Tapper::Producer::Kernel::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Producer::Kernel::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: produce preconditions for a kernel package
-
-        use Moose;
+$Tapper::Producer::Kernel::VERSION = '5.0.0';
+use Moose;
         use YAML;
 
         use 5.010;
@@ -85,7 +80,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -111,7 +106,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
