@@ -1,14 +1,9 @@
 ## no critic (RequireUseStrict)
 package Tapper::Producer::SimnowKernel;
-BEGIN {
-  $Tapper::Producer::SimnowKernel::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Producer::SimnowKernel::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: produce preconditions for simnow kernel testing
-
-        use YAML;
+$Tapper::Producer::SimnowKernel::VERSION = '5.0.0';
+use YAML;
 
         use 5.010;
         use Moose;
@@ -93,7 +88,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -120,7 +115,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
