@@ -1,14 +1,9 @@
 ## no critic (RequireUseStrict)
 package Tapper::Producer::Temare;
-BEGIN {
-  $Tapper::Producer::Temare::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Producer::Temare::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: produce preconditions via temare
-
-        use Moose;
+$Tapper::Producer::Temare::VERSION = '5.0.0';
+use Moose;
         use File::Temp 'tempfile';
         use YAML       'LoadFile';
         use Tapper::Config;
@@ -53,7 +48,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -77,7 +72,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
